==> haskell-servant-client-core-0.20.3.0-43.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-client-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-client-core
version:              0.20.3.0
visibility:           public
id:                   servant-client-core-0.20.3.0-9piRNUKE2ioC3q9igytHDR
key:                  servant-client-core-0.20.3.0-9piRNUKE2ioC3q9igytHDR
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:
    Core functionality and class for client function generation for servant APIs

description:
    This library provides backend-agnostic generation of client functions. For
    more information, see the README.

category:             Servant, Web
abi:                  e56c669858c66deea1ade3050edd088c
exposed:              True
exposed-modules:
    Servant.Client.Core Servant.Client.Core.Auth
    Servant.Client.Core.BaseUrl Servant.Client.Core.BasicAuth
    Servant.Client.Core.ClientError Servant.Client.Core.HasClient
    Servant.Client.Core.MultiVerb.ResponseUnrender
    Servant.Client.Core.Reexport Servant.Client.Core.Request
    Servant.Client.Core.Response Servant.Client.Core.RunClient
    Servant.Client.Core.ServerSentEvents Servant.Client.Free
    Servant.Client.Generic

hidden-modules:       Servant.Client.Core.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/servant-client-core-0.20.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/servant-client-core-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/servant-client-core-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-client-core
hs-libraries:         HSservant-client-core-0.20.3.0-9piRNUKE2ioC3q9igytHDR
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4
    base64-bytestring-1.2.1.0-DIdtXjiFLF0sICzGCxvgr bytestring-0.11.5.3
    constraints-0.14.2-5Hasiz3qGyu5OkYwKIAmXY containers-0.6.7
    deepseq-1.4.8.1 exceptions-0.10.7 free-5.2-3fckYVSYEwRA3sQVkSQiQV
    http-media-0.8.1.1-IVN9WTR9Vpq260gzanGeUu
    http-types-0.12.4-AM56akyPNdKBTyuGfrlHOS
    network-uri-2.6.4.2-69jfmnohyG88ZQKNy7a5sS
    safe-0.3.21-6ywRAlXnRFuBscoqJeUz3o
    servant-0.20.3.0-FMI4LG4x1t4Dir4ovtxFzm
    sop-core-0.5.0.2-1KOi1hjK2a7LcGI7gMT7tS template-haskell-2.20.0.0
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-servant-client-core/html/servant-client-core.haddock

haddock-html:         /usr/share/doc/haskell-servant-client-core/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-client-core-0.20.3.0-44-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-client-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-client-core
version:              0.20.3.0
visibility:           public
id:                   servant-client-core-0.20.3.0-IG567hdFs9P773jrRHbW0f
key:                  servant-client-core-0.20.3.0-IG567hdFs9P773jrRHbW0f
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:
    Core functionality and class for client function generation for servant APIs

description:
    This library provides backend-agnostic generation of client functions. For
    more information, see the README.

category:             Servant, Web
abi:                  9215a3e07ee18924f0a1cf10abb4bdbc
exposed:              True
exposed-modules:
    Servant.Client.Core Servant.Client.Core.Auth
    Servant.Client.Core.BaseUrl Servant.Client.Core.BasicAuth
    Servant.Client.Core.ClientError Servant.Client.Core.HasClient
    Servant.Client.Core.MultiVerb.ResponseUnrender
    Servant.Client.Core.Reexport Servant.Client.Core.Request
    Servant.Client.Core.Response Servant.Client.Core.RunClient
    Servant.Client.Core.ServerSentEvents Servant.Client.Free
    Servant.Client.Generic

hidden-modules:       Servant.Client.Core.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/servant-client-core-0.20.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/servant-client-core-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/servant-client-core-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-client-core
hs-libraries:         HSservant-client-core-0.20.3.0-IG567hdFs9P773jrRHbW0f
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4
    base64-bytestring-1.2.1.0-AZbYiNuTo1lLfA6t4c9Fhh
    bytestring-0.11.5.3 constraints-0.14.2-HITsp0guL9Z2vC96u1IEz
    containers-0.6.7 deepseq-1.4.8.1 exceptions-0.10.7
    free-5.2-CP2SAI6deNWCXG1eD5QmMc
    http-media-0.8.1.1-ESBCw4Dvl5R7GQFVDBq0Rc
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    network-uri-2.6.4.2-ImBkmHhWmdwGJdqs22FerI
    safe-0.3.21-7oQO4KcgDWt1YhK3ifcAwa
    servant-0.20.3.0-EGizVGIAZ794yRWvR5V6rz
    sop-core-0.5.0.2-1KOi1hjK2a7LcGI7gMT7tS template-haskell-2.20.0.0
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-servant-client-core/html/servant-client-core.haddock

haddock-html:         /usr/share/doc/haskell-servant-client-core/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
